==> onecx-parameters-client-0.37.0-sources.jar: gen/org/tkit/onecx/parameters/v1/model/ParameterInfo.java <==
package gen.org.tkit.onecx.parameters.v1.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.lang.reflect.Type;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
public class ParameterInfo  {

    private Long count;
    private Object defaultValue;
    private Object currentValue;

    /**
    * Get count
    * @return count
    **/
    @JsonProperty("count")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public Long getCount() {
        return count;
    }

    /**
     * Set count
     **/
    public void setCount(Long count) {
        this.count = count;
    }

    public ParameterInfo count(Long count) {
        this.count = count;
        return this;
    }

    /**
    * Get defaultValue
    * @return defaultValue
    **/
    @JsonProperty("defaultValue")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public Object getDefaultValue() {
        return defaultValue;
    }

    /**
     * Set defaultValue
     **/
    public void setDefaultValue(Object defaultValue) {
        this.defaultValue = defaultValue;
    }

    public ParameterInfo defaultValue(Object defaultValue) {
        this.defaultValue = defaultValue;
        return this;
    }

    /**
    * Get currentValue
    * @return currentValue
    **/
    @JsonProperty("currentValue")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public Object getCurrentValue() {
        return currentValue;
    }

    /**
     * Set currentValue
     **/
    public void setCurrentValue(Object currentValue) {
        this.currentValue = currentValue;
    }

    public ParameterInfo currentValue(Object currentValue) {
        this.currentValue = currentValue;
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ParameterInfo {\n");

        sb.append("    count: ").append(toIndentedString(count)).append("\n");
        sb.append("    defaultValue: ").append(toIndentedString(defaultValue)).append("\n");
        sb.append("    currentValue: ").append(toIndentedString(currentValue)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
    public static class ParameterInfoQueryParam  {

        @jakarta.ws.rs.QueryParam("count")
        private Long count;
        @jakarta.ws.rs.QueryParam("defaultValue")
        private Object defaultValue;
        @jakarta.ws.rs.QueryParam("currentValue")
        private Object currentValue;

        /**
        * Get count
        * @return count
        **/
        @JsonProperty("count")
        public Long getCount() {
            return count;
        }

        /**
         * Set count
         **/
        public void setCount(Long count) {
            this.count = count;
        }

        public ParameterInfoQueryParam count(Long count) {
            this.count = count;
            return this;
        }

        /**
        * Get defaultValue
        * @return defaultValue
        **/
        @JsonProperty("defaultValue")
        public Object getDefaultValue() {
            return defaultValue;
        }

        /**
         * Set defaultValue
         **/
        public void setDefaultValue(Object defaultValue) {
            this.defaultValue = defaultValue;
        }

        public ParameterInfoQueryParam defaultValue(Object defaultValue) {
            this.defaultValue = defaultValue;
            return this;
        }

        /**
        * Get currentValue
        * @return currentValue
        **/
        @JsonProperty("currentValue")
        public Object getCurrentValue() {
            return currentValue;
        }

        /**
         * Set currentValue
         **/
        public void setCurrentValue(Object currentValue) {
            this.currentValue = currentValue;
        }

        public ParameterInfoQueryParam currentValue(Object currentValue) {
            this.currentValue = currentValue;
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class ParameterInfoQueryParam {\n");

            sb.append("    count: ").append(toIndentedString(count)).append("\n");
            sb.append("    defaultValue: ").append(toIndentedString(defaultValue)).append("\n");
            sb.append("    currentValue: ").append(toIndentedString(currentValue)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }}

==> onecx-parameters-client-1.6.0-sources.jar: gen/org/tkit/onecx/parameters/v1/model/ParameterInfo.java <==
package gen.org.tkit.onecx.parameters.v1.model;


import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import com.fasterxml.jackson.annotation.JsonProperty;

@io.quarkus.runtime.annotations.RegisterForReflection
@com.fasterxml.jackson.annotation.JsonIgnoreProperties(ignoreUnknown = true)
public class ParameterInfo  {

    private Long count;
    private Object defaultValue;
    private Object currentValue;

    /**
    * Get count
    * @return count
    **/
    @JsonProperty("count")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public Long getCount() {
        return count;
    }

    /**
     * Set count
     **/
    public void setCount(Long count) {
        this.count = count;
    }

    public ParameterInfo count(Long count) {
        this.count = count;
        return this;
    }

    /**
    * Get defaultValue
    * @return defaultValue
    **/
    @JsonProperty("defaultValue")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public Object getDefaultValue() {
        return defaultValue;
    }

    /**
     * Set defaultValue
     **/
    public void setDefaultValue(Object defaultValue) {
        this.defaultValue = defaultValue;
    }

    public ParameterInfo defaultValue(Object defaultValue) {
        this.defaultValue = defaultValue;
        return this;
    }

    /**
    * Get currentValue
    * @return currentValue
    **/
    @JsonProperty("currentValue")
    @com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
    public Object getCurrentValue() {
        return currentValue;
    }

    /**
     * Set currentValue
     **/
    public void setCurrentValue(Object currentValue) {
        this.currentValue = currentValue;
    }

    public ParameterInfo currentValue(Object currentValue) {
        this.currentValue = currentValue;
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ParameterInfo {\n");

        sb.append("    count: ").append(toIndentedString(count)).append("\n");
        sb.append("    defaultValue: ").append(toIndentedString(defaultValue)).append("\n");
        sb.append("    currentValue: ").append(toIndentedString(currentValue)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Compares this object to the specified object. The result is
     * {@code true} if and only if the argument is not
     * {@code null} and is a {@code ParameterInfo} object that
     * contains the same values as this object.
     *
     * @param   obj   the object to compare with.
     * @return  {@code true} if the objects are the same;
     *          {@code false} otherwise.
     **/
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null || getClass() != obj.getClass()) return false;

        ParameterInfo model = (ParameterInfo) obj;

        return java.util.Objects.equals(count, model.count) &&
        java.util.Objects.equals(defaultValue, model.defaultValue) &&
        java.util.Objects.equals(currentValue, model.currentValue);
    }

    /**
     * Returns a hash code for a {@code ParameterInfo}.
     *
     * @return a hash code value for a {@code ParameterInfo}.
     **/
    @Override
    public int hashCode() {
        return java.util.Objects.hash(count,
        defaultValue,
        currentValue);
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @com.fasterxml.jackson.annotation.JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
    public static class ParameterInfoQueryParam  {

        @jakarta.ws.rs.QueryParam("count")
        private Long count;
        @jakarta.ws.rs.QueryParam("defaultValue")
        private Object defaultValue;
        @jakarta.ws.rs.QueryParam("currentValue")
        private Object currentValue;

        /**
        * Get count
        * @return count
        **/
        @com.fasterxml.jackson.annotation.JsonProperty("count")
        public Long getCount() {
            return count;
        }

        /**
         * Set count
         **/
        public void setCount(Long count) {
            this.count = count;
        }

        public ParameterInfoQueryParam count(Long count) {
            this.count = count;
            return this;
        }

        /**
        * Get defaultValue
        * @return defaultValue
        **/
        @com.fasterxml.jackson.annotation.JsonProperty("defaultValue")
        public Object getDefaultValue() {
            return defaultValue;
        }

        /**
         * Set defaultValue
         **/
        public void setDefaultValue(Object defaultValue) {
            this.defaultValue = defaultValue;
        }

        public ParameterInfoQueryParam defaultValue(Object defaultValue) {
            this.defaultValue = defaultValue;
            return this;
        }

        /**
        * Get currentValue
        * @return currentValue
        **/
        @com.fasterxml.jackson.annotation.JsonProperty("currentValue")
        public Object getCurrentValue() {
            return currentValue;
        }

        /**
         * Set currentValue
         **/
        public void setCurrentValue(Object currentValue) {
            this.currentValue = currentValue;
        }

        public ParameterInfoQueryParam currentValue(Object currentValue) {
            this.currentValue = currentValue;
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class ParameterInfoQueryParam {\n");

            sb.append("    count: ").append(toIndentedString(count)).append("\n");
            sb.append("    defaultValue: ").append(toIndentedString(defaultValue)).append("\n");
            sb.append("    currentValue: ").append(toIndentedString(currentValue)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }}
